@@ -26,11 +26,7 @@
 
 #include <QScopedPointer>
 
-template <typename T> using ScopedCPointer = QScopedPointer<T, QScopedPointerPodDeleter>;
-
-namespace PowerDevil {
-    class KWinKScreenHelperEffect;
-}
+class AbstractDpmsHelper;
 
 class PowerDevilDPMSAction : public PowerDevil::Action
 {
@@ -39,7 +35,7 @@ class PowerDevilDPMSAction : public PowerDevil::Action
 
 public:
     explicit PowerDevilDPMSAction(QObject *parent, const QVariantList &);
-    virtual ~PowerDevilDPMSAction() = default;
+    virtual ~PowerDevilDPMSAction();
 
 protected:
     virtual void onProfileUnload();
@@ -59,13 +55,11 @@ private Q_SLOTS:
 private:
     void setKeyboardBrightnessHelper(int brightness);
 
-    bool m_supported = false;
-
     int m_idleTime = 0;
     PowerDevil::PolicyAgent::RequiredPolicies m_inhibitScreen = PowerDevil::PolicyAgent::None;
 
     int m_oldKeyboardBrightness = 0;
-    QScopedPointer<PowerDevil::KWinKScreenHelperEffect> m_fadeEffect;
+    QScopedPointer<AbstractDpmsHelper> m_helper;
 
 };
 
