@@ -52,7 +52,10 @@ PowerDevilUPowerBackend::PowerDevilUPowerBackend(QObject* parent)
     , m_upowerInterface(Q_NULLPTR)
     , m_kbdBacklight(Q_NULLPTR)
     , m_kbdMaxBrightness(0)
-    , m_lidIsPresent(false), m_lidIsClosed(false), m_onBattery(false)
+    , m_lidIsPresent(false)
+    , m_lidIsClosed(false)
+    , m_onBattery(false)
+    , m_isLedBrightnessControl(false)
 {
 
 }
@@ -158,6 +161,7 @@ void PowerDevilUPowerBackend::init()
             [this, brightnessJob]  {
                 if (brightnessJob->error()) {
                     qCWarning(POWERDEVIL) << "org.kde.powerdevil.backlighthelper.brightness failed";
+                    qCDebug(POWERDEVIL) << brightnessJob->errorText();
                     Q_EMIT brightnessSupportQueried(false);
                     return;
                 }
@@ -170,6 +174,7 @@ void PowerDevilUPowerBackend::init()
                     [this, brightnessMaxJob] {
                         if (brightnessMaxJob->error()) {
                             qCWarning(POWERDEVIL) << "org.kde.powerdevil.backlighthelper.brightnessmax failed";
+                            qCDebug(POWERDEVIL) << brightnessMaxJob->errorText();
                         } else {
                             m_brightnessMax = brightnessMaxJob->data()["brightnessmax"].toInt();
                         }
@@ -180,15 +185,21 @@ void PowerDevilUPowerBackend::init()
                         connect(syspathJob, &KJob::result, this,
                             [this, syspathJob] {
                                 if (syspathJob->error()) {
+                                    qCWarning(POWERDEVIL) << "org.kde.powerdevil.backlighthelper.syspath failed";
+                                    qCDebug(POWERDEVIL) << syspathJob->errorText();
                                     Q_EMIT brightnessSupportQueried(false);
                                     return;
                                 }
                                 m_syspath = syspathJob->data()["syspath"].toString();
                                 m_syspath = QFileInfo(m_syspath).readLink();
 
-                                UdevQt::Client *client =  new UdevQt::Client(QStringList("backlight"), this);
-                                connect(client, SIGNAL(deviceChanged(UdevQt::Device)), SLOT(onDeviceChanged(UdevQt::Device)));
-                                Q_EMIT brightnessSupportQueried(true);
+                                m_isLedBrightnessControl = m_syspath.contains(QLatin1String("/leds/"));
+                                if (!m_isLedBrightnessControl) {
+                                    UdevQt::Client *client =  new UdevQt::Client(QStringList("backlight"), this);
+                                    connect(client, SIGNAL(deviceChanged(UdevQt::Device)), SLOT(onDeviceChanged(UdevQt::Device)));
+                                }
+
+                                Q_EMIT brightnessSupportQueried(m_brightnessMax > 0);
                             }
                         );
                         syspathJob->start();
@@ -442,6 +453,10 @@ void PowerDevilUPowerBackend::setBrightness(int value, PowerDevil::BackendInterf
             KAuth::ExecuteJob *job = action.execute();
             // we don't care about the result since executing the job sync is bad
             job->start();
+            if (m_isLedBrightnessControl) {
+                m_cachedBrightnessMap[Screen] = value;
+                slotScreenBrightnessChanged();
+            }
         }
     } else if (type == Keyboard) {
         qCDebug(POWERDEVIL) << "set kbd backlight value: " << value;
@@ -457,7 +472,7 @@ void PowerDevilUPowerBackend::slotScreenBrightnessChanged()
 
     int value = brightness(Screen);
     qCDebug(POWERDEVIL) << "Brightness changed!!";
-    if (value != m_cachedBrightnessMap[Screen]) {
+    if (value != m_cachedBrightnessMap[Screen] || m_isLedBrightnessControl) {
         m_cachedBrightnessMap[Screen] = value;
         onBrightnessChanged(Screen, value, brightnessMax(Screen));
     }
